/**
* DO NOT EDIT THIS FILE.
* See the following change record for more information,
* https://www.drupal.org/node/2815083
* @preserve
**/

/**
 * @file
 * Javascript to initialize singe date time library.
 */
(function ($, Drupal, drupalSettings) {

    
  /**
   * Function to return list of hours / minutes formatted as array.
   *
   * @param {Array} $hours
   *   List for allowed hours as array.
   * @param {string} $type
   *   Granularity for allowed intervals in minutes.
   *
   * @return {Array}
   *   Return minutes formatted in array by allowed intervals.
   */
  function SingleDatetimeAllowTimes($hours, $type) {

    var times = [];

    // Build array.
    $hours.forEach(function (i) {
      // Formatting hours.
      if (i < 10) {
        i = "0" + i;
      }

      // Default granularity is one hour.
      if ($type === 60) {
        times.push(i + ":00");
      }

      // Custom settings, per minutes.
      else {
          var measure = 60 / $type;
          for (var j = 0; j < measure; j++) {
            var minutes = $type * j;
            if (j === 0) {
              minutes = "00";
            } else if (minutes < 10) {
              minutes = "0" + minutes;
            }
            times.push(i + ":" + minutes);
          }
        }
    });
    return times;
  }

  /**
   * Attaches the consultation behavior.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.consultation = {
    attach: function attach(context) {

      // Setting the current language for the calendar.
      var lang = drupalSettings.path.currentLanguage;
	  
	  
	  
      $(context).find("input[data-single-date-time]").once("datePicker").each(function () {
         
         var input = $(this);
		
        // Get widget type.
        var widgetType = input.data("singleDateTime");

        // Get hour format - 12 or 24.
        var hourFormat = input.data("hourFormat");
    
        // Get first day in week from Drupal.
        var dayOfWeekStart = input.data("firstDay");
		
		    var timeselected = false;

        // Default values (used for dates only).
        var format = "Y-m-d";
        var allowTimepicker = false;

        // Get disabled days.
        var disabledWeekDays = [0];
        // Get excluded dates.
        var disabledDates = input.data("excludeDate");

        // Get minimum date.
        var minDate = input.data("minDate");

        // Get maximum date.
        var maxDate = input.data("maxDate");

        // Get start year.
        var yearStart = input.data("yearStart");

        // Get end year.
        var yearEnd = input.data("yearEnd");

        // Set the hour format.
        var formatTime = (hourFormat == "12") ? "g:i:A" : "H:i:A";
		
        var inline = input.data("inline");

        var mask = Boolean(input.data("mask"));

        var theme = input.data("datetimepickerTheme");
        
        // Default empty array. Only calculate later if field type
        // includes times.
		
        var allowTimes = [];
		
        // If is date & time field.
        if (widgetType === "datetime") {
		    format = (hourFormat == "12") ? "Y-m-d g:i:A" : "Y-m-d H:i:A";
            allowTimepicker = true;
		  
          // Get minute granularity, and allowed hours.
               allowTimes = SingleDatetimeAllowTimes(input.data("allowedHours"), input.data("allowTimes"));
		}
		var datamaxtimeWeekday = input.data("maxTimeWeekday");
		 
		var datamaxtimeWeekend = input.data("maxTimeWeekend");
		var current = new Date();
		
		var checkPastTime = function(inputDateTime) {
		  if (typeof(inputDateTime) != "undefined" && inputDateTime !== null) {
				//check past year and month
				if (inputDateTime.getFullYear() < current.getFullYear()) {
					$("#" + input.attr("id")).datetimepicker('reset');
					alert("Sorry! Past date time not allow.");
				} else if ((inputDateTime.getFullYear() == current.getFullYear()) && (inputDateTime.getMonth() < current.getMonth())) {
					$("#" + input.attr("id")).datetimepicker('reset');
					alert("Sorry! Past date time not allow.");
				}
				if (inputDateTime.getDate() == current.getDate()) {
					if (inputDateTime.getHours() < current.getHours()) {
						$("#" + input.attr("id")).datetimepicker('reset');
					}
				}
			}
		};	

		var cnfbtncallback = function (e){
      $("#" + input.attr("id")).datetimepicker('destroy')
      jQuery('.xdsoft_datetimepicker.xdsoft_noselect.xdsoft_.xdsoft_inline').hide();
      jQuery('.webform-submission-consultation-add-form').show();
      jQuery('.companydetail_block').addClass('is-form');
      jQuery("#block-consultationblock .content").append("<button class='back-button booking_back_button' type='button' aria-label='Go to previous page'></button>");
      var backbutton = document.querySelector(".booking_back_button");
         if (backbutton != null) {
          backbutton.addEventListener("click",datetimecallback)
          backbutton.addEventListener("touchstart",datetimecallback)
         } 
    }

    var cancelbtncallback = function (e){
      e.preventDefault();
      jQuery(".confbtn").remove();
      jQuery(".xdsoft_time.xdsoft_current").show();
    }

		ongenerate = function(ct,$i){
       if (timeselected){
		     $("<div class='confbtn'><button type='button' class='cnfbtn'>Confirm</button><button type='button' class='cnlbtn'>Cancel</button></div>").insertAfter(".xdsoft_time.xdsoft_current");
         jQuery(".xdsoft_time.xdsoft_current").hide();
         var cnfbtn = document.querySelector(".cnfbtn");
         if (cnfbtn != null) {
          cnfbtn.addEventListener("click",cnfbtncallback)
          cnfbtn.addEventListener("touchstart",cnfbtncallback)
         } 
         
         var cnlbtn = document.querySelector(".cnlbtn")
         if (cnlbtn != null) {
           cnlbtn.addEventListener("click",cancelbtncallback)
           cnlbtn.addEventListener("touchstart",cancelbtncallback)
        }
		    timeselected = false
		    }
		}
		dateSelected = function (ct,$i){
      var date = ct.getDate();
			var month = ct.getMonth()+1;
			var year = ct.getUTCFullYear();
			var bookdate = date + '-' + month + '-' + year;
	    
			if (date == current.getDate()) {
				this.setOptions({
					minTime: current.getHours()-600 + ':00' //here pass current time hour
				});
			}else {
				this.setOptions({
					minTime: false
				});
			}
			if (ct && ct.getDay() == 6){
			   this.setOptions({
				   maxTime:(datamaxtimeWeekend),formatTime,
				});
			}
		   else
			{
				this.setOptions({
					maxTime:(datamaxtimeWeekday),formatTime,
				});
			}
			jQuery("input[name=slot_booking_date]").val(bookdate);
			jQuery('.xdsoft_timepicker').hide();
			jQuery("input[name=slot_booking_timezone]").val(Intl.DateTimeFormat().resolvedOptions().timeZone);
			jQuery('.xdsoft_datetimepicker.xdsoft_inline').removeClass('no-timepicker');
			jQuery('.companydetail_block').removeClass('is-expanded');
			jQuery('.xdsoft_datepicker.active').addClass('active_timepicker');
      $.ajax({
        type: 'POST',
        url: 'get_booking_dates',
        data:{'current_date':bookdate},
        success: function (data) {
                // Converting JS object to an array
                var allow_time_sloat_array = $.map(data['allow_time_sloat'], function(time_sloat, index){
                    return [time_sloat];
                });
              $("#" + input.attr("id")).data('xdsoft_datetimepicker').setOptions({  
                allowTimes:allow_time_sloat_array,
              });
              jQuery('.xdsoft_timepicker').show();
        }
      });

		}

		timeselectedcallback = function(ct,$i){
      var cHour = ct.getHours();
			var cMin =  (ct.getMinutes()<10?'0':'') + ct.getMinutes();
			var cSec = ct.getSeconds();
			var time = cHour + ':' + cMin;
			jQuery("input[name=slot_detail]").val(time);
		  timeselected = true
		}

    var createCalender = function () {
      $("#" + input.attr("id")).datetimepicker({
          format: format,
          timeHeightInTimePicker:22,
          formatTime: formatTime,
          lazyInit: true,
          timepicker: allowTimepicker,
          todayButton: true,
          dayOfWeekStart: dayOfWeekStart,
          allowTimes: allowTimes,
          disabledWeekDays: disabledWeekDays,
          disabledDates: disabledDates,
          formatDate: "d.m.Y",
          inline: inline,
          mask: mask,
          minDate: minDate,
          maxDate: maxDate,
          yearStart: yearStart,
          yearEnd: yearEnd,
          onChangeDateTime:checkPastTime,
          theme: theme,
          onGenerate : ongenerate,
          onSelectDate:dateSelected,
          onSelectTime:timeselectedcallback,
          minTime:false,
          scrollMonth: false,
          scrollTime: false,
          scrollInput: true,
      });
      jQuery('.xdsoft_timepicker').hide();
    }
	
    var datetimecallback = function (e){
      jQuery('.webform-submission-consultation-add-form, #block-webform h2').hide();
      jQuery('.booking_back_button').remove();
      jQuery('.companydetail_block').removeClass('is-form');
      createCalender()
      jQuery('.xdsoft_datetimepicker.xdsoft_inline').addClass('no-timepicker');
    }
    
    createCalender()
    if (lang === 'pt-br') {
      lang = 'pt-BR';
    }

    if (lang === 'zh-hans') {
      lang = 'zh';
    }

    if (lang === 'zh-hant') {
      lang = 'zh-TW';
    }

    // Explicitly set locale. Does not work with passed variable
    // in setttings above.
    $.datetimepicker.setLocale(lang);
  });
  }
};
})(jQuery, Drupal, drupalSettings);